@@ -36,20 +36,22 @@ class PacketListener
     @sock_arr = sock_arr
     xml = buff = ''
     while true do
-      xml = ''
       begin
+	xml = ''
 	while "\n" != (buff = @sock.gets) do
 	  xml += buff
 	end
+	# puts u8toeuc(xml)
 	xml.gsub!(/\n/, '')
 	doc = Document.new(xml)
 	argv = []
 	doc.elements.each("packet/arg") do |e|
-	  argv.push u8toeuc(e.text)
+	  argv.push u8toeuc("#{e.text}")
 	end
 	method_name = doc.root.attributes['method_name']
 	send method_name, *argv
       rescue
+	# puts $!, $@
 	@sock.close
 	sock_arr.delete @sock
 	Thread.exit
