@@ -22,12 +22,28 @@ class PosDialog < Gtk::Dialog
   end
 end
 
+class SyncDialog < PosDialog
+  attr_accessor :sync_bar
+  def initialize(max)
+    super()
+    @max = max
+    set_title("ʥǡƱ...")
+    vbox.add Gtk::Label.new("ʥǡƱ....")
+    @sync_bar = Gtk::ProgressBar.new
+    vbox.add @sync_bar
+    vbox.border_width = 10
+    show_all
+    self
+  end
+end
+
+
 class ConfigDialog < PosDialog
   def initialize(conf)
     super()
     @conf = conf
     set_title("opossum ꥦɥ")
-    table = Gtk::Table.new(2, 5, false)
+    table = Gtk::Table.new(2, 6, false)
     table.set_col_spacings 10
     table.set_row_spacings 10
     vbox.border_width = 10
@@ -75,6 +91,14 @@ class ConfigDialog < PosDialog
     entry_arr.push entry
     table.attach(label1,  0, 1, 3, 4)
     table.attach(entry,   1, 2, 3, 4)
+    label1 = Gtk::Label.new("եȥ :")
+    label1.set_alignment(1, 0.5)
+    entry = Gtk::Entry.new
+    entry.set_text(conf['fontsize'])
+    entry_arr.push entry
+    table.attach(label1,  0, 1, 4, 5)
+    table.attach(entry,   1, 2, 4, 5)
+    
     button_ok     = Gtk::Button.new(" OK ")
     button_cancel = Gtk::Button.new(" 󥻥 ")
     action_area.add button_ok
@@ -334,16 +358,26 @@ class SearchItemWin < Gtk::Window
 	  where_clause.push "price = #{price_text}"
 	end
 	sql += where_clause.join(" and ")
-	sql += " order by item_id "
       end
+      sql += " order by item_id "
       @sql = sql
       update_item_list
     end
+    hbox = Gtk::HBox.new
+    sync_button  = Gtk::Button.new("ʥǡƱ")
+    sync_button.signal_connect('clicked') do |w|
+      sth = @dbh.prepare("delete from tbl_item")
+      sth.execute
+      Packet.new(sock, "sync_item", "hoge").send
+    end
+    hbox.add sync_button
+
     close_button = Gtk::Button.new("Ĥ")
+    hbox.add close_button
     close_button.signal_connect('clicked') do |w|
       destroy
     end
-    vbox.pack_start(close_button, false)
+    vbox.pack_start(hbox, false)
     self.show_all
   end
   def update_item_list
